@@ -1,5 +1,7 @@
 """
 Main CLI entrypoint.
+
+Copyright 2025 Vlad Emelianov
 """
 
 import sys
@@ -9,14 +11,14 @@ def print_info() -> None:
     """
     Print package info to stdout.
     """
-    print(
-        "Type annotations for boto3.AgentsforBedrockRuntime 1.34.106\n"
-        "Version:         1.34.106\n"
-        "Builder version: 7.24.0\n"
+    sys.stdout.write(
+        "Type annotations for boto3 AgentsforBedrockRuntime 1.36.11\n"
+        "Version:         1.36.11\n"
+        "Builder version: 8.9.0\n"
         "Docs:            https://youtype.github.io/boto3_stubs_docs/mypy_boto3_bedrock_agent_runtime//\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/bedrock-agent-runtime.html#AgentsforBedrockRuntime\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/bedrock-agent-runtime.html#agentsforbedrockruntime\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
-        "Changelog:       https://github.com/youtype/mypy_boto3_builder/releases"
+        "Changelog:       https://github.com/youtype/mypy_boto3_builder/releases\n"
     )
 
 
@@ -24,7 +26,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.34.106")
+    sys.stdout.write("1.36.11\n")
 
 
 def main() -> None:
@@ -32,7 +34,8 @@ def main() -> None:
     Main CLI entrypoint.
     """
     if "--version" in sys.argv:
-        return print_version()
+        print_version()
+        return
     print_info()
 
 
